.. image:: https://github.com/MacHu-GWU/docfly-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/docfly-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/docfly-project/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/MacHu-GWU/docfly-project

.. image:: https://readthedocs.org/projects/docfly/badge/?version=latest
    :target: https://docfly.readthedocs.io/?badge=latest
    :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/docfly.svg
    :target: https://pypi.python.org/pypi/docfly

.. image:: https://img.shields.io/pypi/l/docfly.svg
    :target: https://pypi.python.org/pypi/docfly

.. image:: https://img.shields.io/pypi/pyversions/docfly.svg
    :target: https://pypi.python.org/pypi/docfly

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/docfly-project

------


.. image:: https://img.shields.io/badge/Link-Document-blue.svg
      :target: https://docfly.readthedocs.io/index.html

.. image:: https://img.shields.io/badge/Link-API-blue.svg
      :target: https://docfly.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Source_Code-blue.svg
      :target: https://docfly.readthedocs.io/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
      :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
      :target: https://github.com/MacHu-GWU/docfly-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
      :target: https://github.com/MacHu-GWU/docfly-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
      :target: https://github.com/MacHu-GWU/docfly-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
      :target: https://pypi.org/pypi/docfly#files


Welcome to ``docfly`` Documentation
==============================================================================
``docfly`` is a utility tools to minimize your work using `sphinx-doc <http://www.sphinx-doc.org/en/stable/index.html>`_

Full document can be cond `HERE <https://docfly.readthedocs.io/>`_

**Feature**:

- Automatic API Reference Doc Generation.
- Easy Table of Content directive Generation (``.. toctree::``).


.. _install:

Install
------------------------------------------------------------------------------

``docfly`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install docfly

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade docfly